/*
 * The TaskJuggler Project Management Software
 *
 * Copyright (c) 2001, 2002, 2003, 2004, 2005 by Chris Schlaeger <cs@kde.org>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of version 2 of the GNU General Public License as
 * published by the Free Software Foundation.
 *
 * $Id$
 */
#ifndef _ReportLayers_h_
#define _ReportLayers_h_

#define TJRL_BACKGROUND 0
#define TJRL_BACKLINES 1
#define TJRL_OFFTIME 2
#define TJRL_GRIDLINES 3
#define TJRL_GRIDLABLES 4
#define TJRL_HIGHLIGHT 5
#define TJRL_NOWLINE 6
#define TJRL_TASKS 10
#define TJRL_TASKCOMP 15
#define TJRL_DEPARROWS 16
#define TJRL_LOADBARS 10
#define TJRL_LOADBARFRAMES 11

#endif

